const sign = require("./sign");
const cloud = require("tencentcloud-sdk-nodejs");
const config = require("./config");

const CmeClient = cloud.cme.v20191029.Client;

const clientConfig = {
  // 腾讯云认证信息
  credential: {
    secretId: config.secretId,
    secretKey: config.secretKey
  },
  // 产品地域
  region: config.region,
  profile: {}
};
const client = new CmeClient(clientConfig);

function getSign() {
  const request = {};
  request.Platform = config.platform;

  let signature = sign.getSign(config.userId);
  let uploadsignature = sign.getUploadSign(config.userId);
  return {
    // 登录签名
    signature: signature,
    // 上传签名
    uploadSignature: uploadsignature,
    // 返回账户信息用于微剪上传素材
    accountInfo: {
      Id: config.teamId,
      Type: config.userType
    }
  };
}
function getTemplateList() {
  return new Promise((resolve, reject) => {
    const request = {};
    request.Platform = config.platform;
    let scope = {};
    scope.Owner = {
      Type: config.userType,
      Id: config.teamId
    };
    request.SearchScopes = [scope];
    client.SearchMaterial(request, (err, response) => {
      if (err) {
        reject({
          errMsg: "请求失败",
          errCode: "1000001",
          err: JSON.stringify(err)
        });
      } else {
        // 过滤出模板
        const list = response.MaterialInfoSet.filter(
          i => i.BasicInfo && i.BasicInfo.MaterialType === "VIDEO_EDIT_TEMPLATE"
        );
        let finalList = {
          tabs: [
            {
              key: "default",
              name: "精选",
              list: list.map(item => {
                return {
                  materialId: item.BasicInfo.MaterialId,
                  thumbUrl: item.BasicInfo.PreviewUrl,
                  yunjian: true,
                  key: item.BasicInfo.MaterialId,
                  name: item.BasicInfo.Name
                };
              })
            }
          ]
        };
        resolve({
          list: finalList
        });
      }
    });
  });
}
function exportFromYunjian({ tracks, title }) {
  return new Promise((resolve, reject) => {
    const request = {};
    request.Platform = config.platform;
    request.Definition = 21; // 固定数值
    request.ExportDestination = "CME"; // 固定数值
    request.TrackData = JSON.stringify(tracks);
    request.CMEExportInfo = {
      Name: title,
      Owner: {
        Type: config.userType,
        Id: config.teamId
      }
    };
    request.Operator = config.userId;
    client.ExportVideoByEditorTrackData(request, (err, response) => {
      if (err) {
        reject({
          errMsg: "请求失败",
          errCode: "1000001",
          err: JSON.stringify(err)
        });
      } else {
        resolve(response);
      }
    });
  });
}
function describeTaskDetail({ taskId }) {
  return new Promise((resolve, reject) => {
    const request = {
      Platform: config.platform,
      TaskId: taskId,
      Operator: config.userId
    };
    client.DescribeTaskDetail(request, (err, response) => {
      if (err) {
        reject({
          errMsg: "请求失败",
          errCode: "1000001",
          err: JSON.stringify(err)
        });
      } else {
        resolve(response)
      }
    });
  })
  
}

module.exports = {
  getSign,
  getTemplateList,
  exportFromYunjian,
  describeTaskDetail
}
