const querystring = require('querystring');
const crypto = require('crypto');
const config = require('./config');

module.exports = {
  getSign(userId) {
    let currentTimeStamp = Math.round(new Date().getTime() / 1000)
    let expireTime = currentTimeStamp + 60 * 60 * 24
    let args = {
      secretId: config.secretId,
      currentTimeStamp,
      expireTime,
      random: Math.round(Math.random() * Math.pow(2, 32)),
      platform: config.platform,
      action: 'Login',
      userId,
    }
    return genSha1Sign(args)
  },
  getUploadSign(userId) {
    let currentTimeStamp = Math.round(new Date().getTime() / 1000)
    let expireTime = currentTimeStamp + 60 * 60 * 24
    let args = {
      secretId: config.secretId,
      currentTimeStamp,
      expireTime,
      random: Math.round(Math.random() * Math.pow(2, 32)),
      platform: config.platform,
      action: 'Upload',
      userId,
    }
    return genSha1Sign(args)
  },
  // 申请打开项目签名，官网链接[]
  getOpenProjectSign(projectId, userId) {
    // eslint-disable-next-line radix
    const current = parseInt((new Date()).getTime() / 1000);
    const expired = current + 86400;  // 签名有效期：1天

    const args = {
      secretId: config.secretId,
      currentTimeStamp: current,
      expireTime: expired,
      // eslint-disable-next-line no-restricted-properties
      random: Math.round(Math.random() * Math.pow(2, 32)),
      platform: config.platform,
      projectId,
      userId,
      action: 'OpenProject'
    };
    console.debug('openProject args:', args);
    return genSha1Sign(args);
  }
};

function getSafeBase64(base64) {
  return base64.replace(/\+/g, '-')
  .replace(/\//g, '_').replace(/=/g,'');
}
function genSha1Sign(args) {
  const original = querystring.stringify(args);
  const originalBuffer = Buffer.from(original, 'utf8');
  const hmac = crypto.createHmac('sha1', config.secretKey);
  const hmacBuffer = hmac.update(originalBuffer).digest();
  const signature = Buffer.concat([hmacBuffer, originalBuffer]).toString('base64');
  return getSafeBase64(signature);
}
